#!/usr/bin/python

import os.path
import wx
import ticonverter

class MainFrame(wx.Frame):
    """Class with the Frame, the GUI and the GUI Functions"""
    def __init__(self, parent,id):
        """Displays the frame, creates the GUI"""
        wx.Frame.__init__(self, parent,id,'Croquette', size=(660,590))
        self.create_gui()
        self.dirname = ""
        self.parser = ticonverter.Parser()
        
    def on_open(self, event):
        """Opens file for reading."""
        dlg = wx.FileDialog(self, "Open a file", self.dirname, 
                            "", "*.*", wx.OPEN)
        if dlg.ShowModal() == wx.ID_OK:
            self.file_name=dlg.GetFilename()
            self.dir_name=dlg.GetDirectory()
            file_handle=open(os.path.join(self.dir_name, self.file_name), 'rb')
            
            file_handle.close()
            
            self.SetTitle("%s - Croquette" % self.file_name)
            self.text_input.SetValue(self.parser.convert_8xp_to_string(
                                     os.path.join(self.dir_name, 
                                     self.file_name)))
        dlg.Destroy()
    
    def on_save(self, event):
        """Saves a file into 8XP"""
        dlg = wx.FileDialog(self, "Save a file", self.dirname, 
                            "", "8xp Files (.8xp)|*.8xp|", 
                            wx.SAVE | wx.OVERWRITE_PROMPT)
        if dlg.ShowModal() == wx.ID_OK:
            
            #Dirty hack to add .8xp to file ending
            self.file_name=dlg.GetFilename()
            if self.file_name[-4:].upper() != ".8XP":
                self.file_name += ".8xp"
            self.file_name = self.file_name.encode("ascii")
            
            self.dir_name=dlg.GetDirectory()
            self.path = os.path.join(self.dir_name, self.file_name)

            self.parser.convert_string_to_8xp(self.text_input.GetValue(),
                                              self.path, 
                                              self.file_name[:-4])
            
            self.SetTitle("%s - Croquette" % self.file_name)
        dlg.Destroy()
        
    def create_gui(self):
        """Creates and displays the GUI and binds the events"""
        
        #Menu Bar Code
        menuBar = wx.MenuBar()
        
        fileMenu = wx.Menu()
        open_id = wx.NewId()
        fileMenu.Append(open_id, "Open\tCtrl+O")
        save_id = wx.NewId()
        fileMenu.Append(save_id, "Save\tCtrl+S")
        
        menuBar.Append(fileMenu, "File")
        
        self.SetMenuBar(menuBar)
        #End of Menu Bar Code
        
        self.text_input=wx.TextCtrl(self,size=(1366,768),
                                    style=wx.TE_MULTILINE)
        
        self.Bind(wx.EVT_MENU, self.on_open, id=open_id)
        self.Bind(wx.EVT_MENU, self.on_save, id=save_id)
        
if __name__=='__main__':
    """Displays the GUI and starts the GUI Loop"""
    app = wx.PySimpleApp()
    frame = MainFrame(parent=None, id=-1)
    frame.Show()
    frame.Maximize()
    app.MainLoop()
